Struct rfw::ecs::query::EntityFetch [−][src]
pub struct EntityFetch { /* fields omitted */ }Trait Implementations
type State = EntityStateReturns true if (and only if) every table of every archetype matched by this Fetch contains all of the matched components. This is used to select a more efficient “table iterator” for “dense” queries. If this returns true, Fetch::set_table and Fetch::table_fetch will be called for iterators If this returns false, Fetch::set_archetype and Fetch::archetype_fetch will be called for iterators Read more
pub unsafe fn init(
_world: &World,
_state: &<EntityFetch as Fetch<'w>>::State,
_last_change_tick: u32,
_change_tick: u32
) -> EntityFetch
pub unsafe fn init(
_world: &World,
_state: &<EntityFetch as Fetch<'w>>::State,
_last_change_tick: u32,
_change_tick: u32
) -> EntityFetchCreates a new instance of this fetch. Read more
pub unsafe fn set_archetype(
&mut self,
_state: &<EntityFetch as Fetch<'w>>::State,
archetype: &Archetype,
_tables: &Tables
)
pub unsafe fn set_archetype(
&mut self,
_state: &<EntityFetch as Fetch<'w>>::State,
archetype: &Archetype,
_tables: &Tables
)Fetch Self::Item for the given table_row in the current Table. This must always be
called after Fetch::set_table with a table_row in the range of the current Table Read more
pub unsafe fn archetype_fetch(
&mut self,
archetype_index: usize
) -> <EntityFetch as Fetch<'w>>::Item
pub unsafe fn archetype_fetch(
&mut self,
archetype_index: usize
) -> <EntityFetch as Fetch<'w>>::ItemFetch Self::Item for the given archetype_index in the current Archetype. This must
always be called after Fetch::set_archetype with an archetype_index in the range of
the current Archetype Read more
SAFE: access is read only