Struct rfw::ecs::storage::ComponentSparseSet[][src]

pub struct ComponentSparseSet { /* fields omitted */ }

Implementations

Inserts the entity key and component value pair into this sparse set. The caller is responsible for ensuring the value is not dropped. This collection will drop the value when needed.

Safety

The value pointer must point to a valid address that matches the Layout inside the ComponentInfo given when constructing this sparse set.

Safety

ensure the same entity is not accessed twice at the same time

Safety

ensure the same entity is not accessed twice at the same time

Safety

ensure the same entity is not accessed twice at the same time

Removes the entity from this sparse set and returns a pointer to the associated value (if it exists). It is the caller’s responsibility to drop the returned ptr (if Some is returned).