Struct rfw::prelude::Vec3 [−][src]
#[repr(transparent)]pub struct Vec3(_);
A 3-dimensional vector without SIMD support.
Implementations
Creates a Vec2 from the x and y elements of self, discarding z.
Truncation may also be performed by using self.xy() or Vec2::from().
Creates a vector from the elements in if_true and if_false, selecting which to use
for each element of self.
A true element in the mask uses the corresponding element from if_true, and false
uses the element from if_false.
Returns a vector containing the mininum values for each element of self and other.
In other words this computes [self.x.max(other.x), self.y.max(other.y), ..].
Returns a vector containing the maximum values for each element of self and other.
In other words this computes [self.x.max(other.x), self.y.max(other.y), ..].
Component-wise clamping of values, similar to f32::clamp.
Each element in min must be less-or-equal to the corresponing element in max.
Panics
Will panic if min is greater than max when glam_assert is enabled.
Returns the horizontal minimum of self.
In other words this computes min(x, y, ..).
Returns the horizontal maximum of self.
In other words this computes max(x, y, ..).
Returns a vector mask containing the result of a == comparison for each element of
self and other.
In other words, this computes [self.x == other.x, self.y == other.y, ..] for all
elements.
Returns a vector mask containing the result of a != comparison for each element of
self and other.
In other words this computes [self.x != other.x, self.y != other.y, ..] for all
elements.
Returns a vector mask containing the result of a >= comparison for each element of
self and other.
In other words this computes [self.x >= other.x, self.y >= other.y, ..] for all
elements.
Returns a vector mask containing the result of a > comparison for each element of
self and other.
In other words this computes [self.x > other.x, self.y > other.y, ..] for all
elements.
Returns a vector mask containing the result of a <= comparison for each element of
self and other.
In other words this computes [self.x <= other.x, self.y <= other.y, ..] for all
elements.
Returns a vector mask containing the result of a < comparison for each element of
self and other.
In other words this computes [self.x < other.x, self.y < other.y, ..] for all
elements.
Creates a vector from the first N values in slice.
Panics
Panics if slice is less than N elements long.
Writes the elements of self to the first N elements in slice.
Panics
Panics if slice is less than N elements long.
Returns a vector containing the absolute value of each element of self.
Returns a vector with elements representing the sign of self.
1.0if the number is positive,+0.0orINFINITY-1.0if the number is negative,-0.0orNEG_INFINITYNANif the number isNAN
Returns true if, and only if, all elements are finite. If any element is either
NaN, positive or negative infinity, this will return false.
Performs is_nan on each element of self, returning a vector mask of the results.
In other words, this computes [x.is_nan(), y.is_nan(), z.is_nan(), w.is_nan()].
Computes the squared length of self.
This is faster than length() as it avoids a square root operation.
Computes 1.0 / length().
For valid results, self must not be of length zero.
Computes the Euclidean distance between two points in space.
Compute the squared euclidean distance between two points in space.
Returns self normalized to length 1.0.
For valid results, self must not be of length zero, nor very close to zero.
See also Self::try_normalize and Self::normalize_or_zero.
Panics
Will panic if self is zero length when glam_assert is enabled.
Returns self normalized to length 1.0 if possible, else returns None.
In particular, if the input is zero (or very close to zero), or non-finite,
the result of this operation will be None.
See also Self::normalize_or_zero.
Returns self normalized to length 1.0 if possible, else returns zero.
In particular, if the input is zero (or very close to zero), or non-finite, the result of this operation will be zero.
See also Self::try_normalize.
Returns whether self is length 1.0 or not.
Uses a precision threshold of 1e-6.
Returns the vector projection of self onto other.
other must be of non-zero length.
Panics
Will panic if other is zero length when glam_assert is enabled.
Returns the vector rejection of self from other.
The vector rejection is the vector perpendicular to the projection of self onto
other, in other words the result of self - self.project_onto(other).
other must be of non-zero length.
Panics
Will panic if other has a length of zero when glam_assert is enabled.
Returns the vector projection of self onto other.
other must be normalized.
Panics
Will panic if other is not normalized when glam_assert is enabled.
Returns the vector rejection of self from other.
The vector rejection is the vector perpendicular to the projection of self onto
other, in other words the result of self - self.project_onto(other).
other must be normalized.
Panics
Will panic if other is not normalized when glam_assert is enabled.
Returns a vector containing the nearest integer to a number for each element of self.
Round half-way cases away from 0.0.
Returns a vector containing the largest integer less than or equal to a number for each
element of self.
Returns a vector containing the smallest integer greater than or equal to a number for
each element of self.
Returns a vector containing the fractional part of the vector, e.g. self - self.floor().
Note that this is fast but not precise for large numbers.
Returns a vector containing e^self (the exponential function) for each element of
self.
Returns a vector containing each element of self raised to the power of n.
Returns a vector containing the reciprocal 1.0/n of each element of self.
Performs a linear interpolation between self and other based on the value s.
When s is 0.0, the result will be equal to self. When s is 1.0, the result
will be equal to other.
Returns true if the absolute difference of all elements between self and other is
less than or equal to max_abs_diff.
This can be used to compare if two vectors contain similar elements. It works best when
comparing with a known value. The max_abs_diff that should be used used depends on
the values being compared against.
For more see comparing floating point numbers.
Returns a vector with a length no less than min and no more than max
Panics
Will panic if min is greater than max when glam_assert is enabled.
Returns a vector with a length no more than max
Returns a vector with a length no less than min
Returns the angle (in radians) between two vectors.
The input vectors do not need to be unit length however they must be non-zero.
Returns somes vector that is orthogonal to the given one.
The input vector must be finite and non-zero.
The output vector is not necessarily unit-length.
For that use Self::any_orthonormal_vector instead.
Returns any unit-length vector that is orthogonal to the given one. The input vector must be finite and non-zero.
Panics
Will panic if self is not normalized when glam_assert is enabled.
Given a unit-length vector return two other vectors that together form an orthonormal basis. That is, all three vectors are orthogonal to each other and are normalized.
Panics
Will panic if self is not normalized when glam_assert is enabled.